---
name: "✨ Feature Request"
about: Submit a request for a new feature in nc-time-axis
title: ''
labels: 'New: Feature'
assignees: ''

---

## ✨ Feature Request
<!-- Provide a clear and concise description of the feature proposal -->

## Motivation
<!-- Is your feature request related to an existing issue? -->
<!-- I'm always frustrated when ... -->

## Additional context
<!-- Provide any further information to help us understand -->
<details>
<summary>Click to expand <b>this section...</b></summary>

```
Please add additional verbose information in this section e.g., references, screenshots, listings etc
```
</details>
